summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
Diffstat (limited to 'png.h')
-rw-r--r--png.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/png.h b/png.h
index a1531bc69..ea85288f0 100644
--- a/png.h
+++ b/png.h
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.0.38rc05 - July 25, 2008
* Copyright (c) 1998-2008 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -8,7 +8,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.0.38rc05 - July 25, 2008: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -194,8 +194,8 @@
* 1.2.29 13 10229 12.so.0.29[.0]
* 1.0.37 10 10037 10.so.0.37[.0]
* 1.2.30beta01-04 13 10230 12.so.0.30[.0]
- * 1.0.38rc01-05 10 10038 10.so.0.38[.0]
- * 1.2.30rc01-05 13 10230 12.so.0.30[.0]
+ * 1.0.38rc01-06 10 10038 10.so.0.38[.0]
+ * 1.2.30rc01-06 13 10230 12.so.0.30[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -225,7 +225,7 @@
* If you modify libpng you may insert additional notices immediately following
* this sentence.
*
* libpng versions 1.2.6, August 15, 2004, through 1.0.38rc05, July 25, 2008, are
* Copyright (c) 2004, 2006-2008 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -337,13 +337,13 @@
* Y2K compliance in libpng:
* =========================
*
- * July 25, 2008
+ * July 29, 2008
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.0.38rc05 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -399,9 +399,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.0.38rc05"
+#define PNG_LIBPNG_VER_STRING "1.0.38rc06"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.0.38rc05 - July 25, 2008\n"
+ " libpng version 1.0.38rc06 - July 29, 2008\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 10
@@ -413,7 +413,7 @@
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero: */
-#define PNG_LIBPNG_VER_BUILD 05
+#define PNG_LIBPNG_VER_BUILD 06
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -1458,7 +1458,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_0_38rc05;
+typedef png_structp version_1_0_38rc06;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.0.38rc05 - July 25, 2008
+ * libpng version 1.0.38rc06 - July 29, 2008
* Copyright (c) 1998-2008 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -8,7 +8,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.0.38rc05 - July 25, 2008: Glenn
+ * libpng versions 0.97, January 1998, through 1.0.38rc06 - July 29, 2008: Glenn
* See also "Contributing Authors", below.
*
@@ -225,7 +225,7 @@
* this sentence.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.0.38rc05, July 25, 2008, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.0.38rc06, July 29, 2008, are
* Copyright (c) 2004, 2006-2008 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -337,13 +337,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.0.38rc05 are Y2K compliant. It is my belief that earlier
+ * upward through 1.0.38rc06 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*